/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.attachments;

import java.io.OutputStream;
import java.util.Objects;
import java.util.concurrent.CompletableFuture;

import org.springframework.stereotype.Service;

import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@Service
@RequiredArgsConstructor
class FileRemoteService {

	private final @NonNull FileRestClient restClient;
	private final @NonNull OzgFileMapper ozgFileMapper;

	OzgFile getFile(FileIdentificationData fileIdentificationData, String address) {
		var grpcFileMetadata = restClient.getFileMetadata(fileIdentificationData, address);

		if (Objects.isNull(grpcFileMetadata.getFileMetadata())) {
			LOG.warn("Received file id {} from {}, but getFileMetadata returned empty ", fileIdentificationData.fileId(), address);
			return null;
		}

		return ozgFileMapper.fromGrpcFileMetadata(grpcFileMetadata.getFileMetadata(), fileIdentificationData.fileId());
	}

	CompletableFuture<String> uploadFile(OzgUploadFile uploadFile, String address) {
		var fileIdFuture = new CompletableFuture<String>();
		restClient.uploadFile(uploadFile, address, fileIdFuture);

		return fileIdFuture;
	}

	void downloadFileContent(FileIdentificationData fileIdentificationData, String address, OutputStream out) {
		restClient.downloadFileContent(fileIdentificationData, address, out);
	}

}
