/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.command;

import static de.ozgcloud.antragsraum.WebConfiguration.*;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Component;
import org.springframework.web.client.RestClient;

import de.ozgcloud.antragsraum.WebConfiguration;
import de.ozgcloud.antragsraum.common.RestClientUtils;
import de.ozgcloud.antragsraum.proxy.AntragraumproxyGrpcCommand;
import lombok.extern.log4j.Log4j2;

@Log4j2
@Component
class CommandRestClient {

	static final String COMMAND_URI = "/api/v1/command/{commandId}";

	private final RestClient restClient;

	public CommandRestClient(@Qualifier(WebConfiguration.NACHRICHT_REST_CLIENT) RestClient restClient) {
		this.restClient = restClient;
	}

	public AntragraumproxyGrpcCommand getCommand(String commandId, String address) {
		return restClient.get()
		  .uri(COMMAND_URI, commandId)
		  .header(X_GRPC_ADDRESS, RestClientUtils.sanitizeAddress(address))
		  .retrieve().toEntity(AntragraumproxyGrpcCommand.class).getBody();
	}

}
