/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.events;

import java.util.List;
import java.util.Objects;

import org.springframework.stereotype.Service;

import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@Service
class NachrichtEventRemoteService {

	private final NachrichtEventRestClient restClient;
	private final NachrichtEventMapper mapper;

	NachrichtEvent getNachrichtEventById(String id) {
		var response = restClient.getNachrichtEventById(id);

		return mapper.fromRest(response.getNachricht());
	}

	List<NachrichtEvent> getNachrichtEventsByPostfach(String postfachId) {
		var response = restClient.getNachrichtEventsByPostfach(postfachId);

		if (Objects.isNull(response.getNachrichten())) {
			return List.of();
		}

		return response.getNachrichten().stream().map(mapper::fromRest).toList();
	}

}