/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.nachricht;

import java.util.List;

import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.Size;

import com.fasterxml.jackson.annotation.JsonInclude;

import de.ozgcloud.antragsraum.attachments.OzgFile;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Builder;

@JsonInclude(JsonInclude.Include.NON_NULL)
@Builder(toBuilder = true)
record ReplyNachricht(
  @Size(max = 24, message = "An id is too long")
  @Schema(description = "The id of the Antwort",
	name = "id",
	type = "string",
	example = "66af924b4f1a2560298b45ab"
  )
  @NotEmpty
  String id,
  @Size(max = 24, message = "An id is too long")
  @Schema(description = "The id of the Rückfrage",
	name = "id",
	type = "string",
	example = "66af924b4f1a2560298b45ab"
  )
  @NotEmpty
  String rueckfrageId,
  @Size(max = 36, message = "An id is too long")
  @Schema(description = "The id of the postfach",
	name = "postfachId",
	type = "string",
	example = "28721c6f-b78f-4d5c-a048-19fd2fc429d2"
  )
  String postfachId,
  @Size(max = 24, message = "An id id too long")
  @Schema(description = "The id of the NachrichtEvent in the InfoManager the reply belongs to",
	name = "nachrichtEventId",
	type = "string",
	example = "60af924b4f1a2560298b4567"
  )
  String nachrichtEventId,
  @Schema(description = "The answer to the rueckfrage.",
	name = "message",
	type = "string",
	example = "Im Anhang sind die Dokumente"
  )
  @Size(max = 100_000, message = "Message text too long")
  String message,
  @Schema(description = "The list of the attached file ids. Only the file id is used when sending the reply, The other values are set by the backend")
  @Size(max = 20)
  List<OzgFile> attachments) {

	@Override
	public String toString() {
		return "ReplyNachricht{" +
		  "postfachId='" + postfachId + '\'' +
		  ", nachrichtEventId='" + nachrichtEventId + '\'' +
		  ", id='" + id + '\'' +
		  ", rueckfrageId='" + rueckfrageId + '\'' +
		  ", attachments=" + attachments +
		  ", message=<...masked for privacy..>" +
		  '}';
	}

}
