/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.nachricht;

import java.util.List;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Builder;
import lombok.Getter;

@Builder
@Getter
class Rueckfrage {

	@Schema(description = "The title of the Rueckfrage. This is the title of the Vorgang",
	  name = "title",
	  type = "string",
	  example = "Vorgang Hundesteuer Antrag"
	)
	String title;
	@Schema(description = "The status of the Rueckfrage.",
	  name = "status",
	  type = "string",
	  example = "ANSWERED"
	)
	String status;
	@Schema(description = "The Rueckfrage sent by the clerk",
	  name = "nachricht",
	  type = "Nachricht"
	)
	Nachricht nachricht;
	@Schema(description = "Whether the Rueckfrage is accessible for current user or not",
	  name = "accessible",
	  type = "boolean"
	)
	boolean accessible;
	@Schema(description = "The trust level of the Rueckfrage sent by the clerk",
	  name = "trustLevel",
	  type = "string"
	)
	String trustLevel;
	@Schema(description = "The reply to the Rueckfrage",
	  name = "antworten",
	  type = "ReplyNachricht"
	)
	List<ReplyNachricht> antworten;

	@Override
	public String toString() {
		return "Rueckfrage{" +
		  "title='" + title + '\'' +
		  ", status='" + status + '\'' +
		  ", nachricht=<...masked for privacy..>" +
		  ", accessible=" + accessible +
		  ", trustLevel='" + trustLevel + '\'' +
		  ", antworten=<...masked for privacy..>" +
		  '}';
	}

}
