/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.nachricht;

import org.apache.commons.lang3.StringUtils;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@NoArgsConstructor(access = AccessLevel.PRIVATE)
class TrustLevelMapper {

	static final String TRUST_LEVEL_STORK_QAA_LEVEL_1 = "STORK-QAA-Level-1";
	static final String TRUST_LEVEL_STORK_QAA_LEVEL_2 = "STORK-QAA-Level-2";
	static final String TRUST_LEVEL_STORK_QAA_LEVEL_3 = "STORK-QAA-Level-3";
	static final String TRUST_LEVEL_STORK_QAA_LEVEL_4 = "STORK-QAA-Level-4";
	static final String TRUST_LEVEL_LOW = "LOW";
	static final String TRUST_LEVEL_SUBSTANTIAL = "SUBSTANTIAL";
	static final String TRUST_LEVEL_HIGH = "HIGH";

	static String map(String trustLevel) {
		if (StringUtils.isEmpty(trustLevel)) {
			LOG.info("Received empty trustlevel, setting it to LOW");
			return TRUST_LEVEL_LOW;
		}

		var result = switch (trustLevel) {
			case TRUST_LEVEL_LOW, TRUST_LEVEL_SUBSTANTIAL, TRUST_LEVEL_HIGH -> trustLevel;
			case TRUST_LEVEL_STORK_QAA_LEVEL_3 -> TRUST_LEVEL_SUBSTANTIAL;
			case TRUST_LEVEL_STORK_QAA_LEVEL_4 -> TRUST_LEVEL_HIGH;
			default -> TRUST_LEVEL_LOW;
		};

		LOG.debug("Mapping trust level {} to {}", trustLevel, result);
		return result;
	}

}
