/*
 * Copyright (c) 2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.time.Instant;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.boot.info.BuildProperties;
import org.springframework.http.HttpStatusCode;

@ExtendWith(MockitoExtension.class)
class RootControllerTest {

	@Nested
	class TestWithBuildProperties {

		@Mock
		private BuildProperties buildProperties;

		@InjectMocks
		private RootController rootController;

		@Test
		void shouldHaveStatusOk() {
			var response = rootController.getRoot();

			assertThat(response.getStatusCode()).isEqualTo(HttpStatusCode.valueOf(200));
		}

		@Test
		void shouldHaveBody() {
			var root = rootController.getRoot().getBody();

			assertThat(root).isNotNull();
		}

		@Test
		void shouldHaveBuildVersion() {
			when(buildProperties.getVersion()).thenReturn("123");

			var root = rootController.getRoot().getBody();

			assertThat(root.version()).isEqualTo("123");
		}

		@Test
		void shouldHaveBuildVersionDefault() {
			var root = rootController.getRoot().getBody();

			assertThat(root.version()).isNull();
		}

		@Test
		void shouldHaveBuildTime() {
			Instant buildTime = Instant.now();
			when(buildProperties.getTime()).thenReturn(buildTime);

			var root = rootController.getRoot().getBody();

			assertThat(root.buildTime()).isEqualTo(buildTime);
		}

		@Test
		void shouldHaveBuildTimeDefault() {
			var root = rootController.getRoot().getBody();

			assertThat(root.buildTime()).isNull();
		}

		@Test
		void shouldHaveName() {
			when(buildProperties.getName()).thenReturn("Antragsraum");

			var root = rootController.getRoot().getBody();

			assertThat(root.name()).isEqualTo("Antragsraum");
		}

		@Test
		void shouldHaveNameDefault() {
			var root = rootController.getRoot().getBody();

			assertThat(root.name()).isNull();
		}

		@Test
		void shouldHaveJavaVersion() {
			var root = rootController.getRoot().getBody();

			assertThat(root.javaVersion()).isNotEmpty();
		}

		@Test
		void shouldProduction() {
			var root = rootController.getRoot().getBody();

			assertThat(root.isProduction()).isTrue();
		}

	}

	@Nested
	class TestWithoutBuildProperties {

		private final RootController rootController = new RootController(null);

		@Test
		void shouldHaveStatusOk() {
			var response = rootController.getRoot();

			assertThat(response.getStatusCode()).isEqualTo(HttpStatusCode.valueOf(200));
		}

		@Test
		void shouldHaveBody() {
			var root = rootController.getRoot().getBody();

			assertThat(root).isNotNull();
		}

		@Test
		void shouldHaveBuildVersionDefault() {
			var root = rootController.getRoot().getBody();

			assertThat(root.version()).isNull();
		}

		@Test
		void shouldHaveBuildTimeDefault() {
			var root = rootController.getRoot().getBody();

			assertThat(root.buildTime()).isNull();
		}

		@Test
		void shouldHaveNameDefault() {
			var root = rootController.getRoot().getBody();

			assertThat(root.name()).isNull();
		}

		@Test
		void shouldHaveJavaVersion() {
			var root = rootController.getRoot().getBody();

			assertThat(root.javaVersion()).isNotEmpty();
		}

		@Test
		void shouldProduction() {
			var root = rootController.getRoot().getBody();

			assertThat(root.isProduction()).isTrue();
		}

	}

}