/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.attachments;

import static de.ozgcloud.antragsraum.attachments.OzgFileTestFactory.*;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;

import org.jetbrains.annotations.NotNull;
import org.springframework.http.MediaType;
import org.springframework.web.multipart.MultipartFile;

public class OzgUploadFileTestFactory {

	public final static MultipartFile MULTIPART_FILE = new TestMultipartFile();

	static OzgUploadFile create() {
		return createBuilder().build();
	}

	static OzgUploadFile.OzgUploadFileBuilder createBuilder() {
		return new OzgUploadFile.OzgUploadFileBuilder()
		  .vorgangId(VORGANG_ID)
		  .file(MULTIPART_FILE);
	}

	static class TestMultipartFile implements MultipartFile {

		@Override
		public @NotNull String getName() {
			return "test.txt";
		}

		@Override
		public String getOriginalFilename() {
			return "test.txt";
		}

		@Override
		public String getContentType() {
			return MediaType.TEXT_PLAIN_VALUE;
		}

		@Override
		public boolean isEmpty() {
			return false;
		}

		@Override
		public long getSize() {
			return DATA.length;
		}

		@Override
		public byte @NotNull [] getBytes() throws IOException {
			return DATA.clone();
		}

		@Override
		public @NotNull InputStream getInputStream() throws IOException {
			return new ByteArrayInputStream(DATA);
		}

		@Override
		public void transferTo(final @NotNull File dest) throws IOException, IllegalStateException {
			try (FileOutputStream fos = new FileOutputStream(dest)) {
				fos.write(DATA);
			}
		}

	}

}
