/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.command;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.mockito.junit.jupiter.MockitoExtension;

import de.ozgcloud.antragsraum.common.AddressNotFoundException;
import de.ozgcloud.antragsraum.events.NachrichtEventTestFactory;
import de.ozgcloud.antragsraum.proxy.AntragraumproxyGrpcCommand;

@ExtendWith(MockitoExtension.class)
public class CommandRemoteServiceTest {

	@Spy
	@InjectMocks
	private CommandRemoteService commandRemoteService;

	@Mock
	private CommandRestClient commandRestClient;

	@Mock
	private CommandMapper commandMapper;

	@Nested
	class TestGetCommand {

		@BeforeEach
		void init() {
			when(commandRestClient.getCommand(anyString(), anyString())).thenReturn(GrpcCommandTestFactory.create());
			when(commandMapper.fromRestCommand(any(AntragraumproxyGrpcCommand.class), anyString())).thenReturn(CommandTestFactory.create());
		}

		@Test
		void shouldLoadCommand() {
			var command = commandRemoteService.getCommand(NachrichtEventTestFactory.create(), CommandTestFactory.ID);

			assertThat(command).isInstanceOf(Command.class);
		}

	}

	@Nested
	class TestNoTargetAddressAvailable {

		@BeforeEach
		void init() {
			doThrow(AddressNotFoundException.class).when(commandRestClient).getCommand(anyString(), anyString());
		}

		@Test
		void shouldThrowAddressNotFoundException() {
			var nachrichtEvent = NachrichtEventTestFactory.create();

			assertThatExceptionOfType(AddressNotFoundException.class).isThrownBy(
			  () -> commandRemoteService.getCommand(nachrichtEvent, CommandTestFactory.ID));
		}

	}

}
