/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.antragsraum.command;

import static de.ozgcloud.antragsraum.command.CommandRestClient.*;
import static org.assertj.core.api.Assertions.*;
import static org.springframework.test.web.client.match.MockRestRequestMatchers.*;
import static org.springframework.test.web.client.response.MockRestResponseCreators.*;

import java.util.UUID;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.client.RestClientTest;
import org.springframework.boot.test.web.client.MockServerRestClientCustomizer;
import org.springframework.http.MediaType;
import org.springframework.test.context.junit.jupiter.SpringJUnitConfig;
import org.springframework.test.web.client.MockRestServiceServer;
import org.springframework.web.client.RestClient;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;

@SpringJUnitConfig(classes = { CommandRestClientTestConfiguration.class })
@RestClientTest(CommandRestClient.class)
class CommandRestClientTest {

	final static String ADDRESS = "http://localhost:8382";
	private static final String COMMAND_ID = UUID.randomUUID().toString();

	private CommandRestClient commandRestClient;

	@Autowired
	private RestClient.Builder restClientBuilder;

	@Autowired
	private MockServerRestClientCustomizer customizer;

	private final ObjectMapper objectMapper = new ObjectMapper();

	private final String commandApi = ADDRESS + COMMAND_URI.replace("{commandId}", COMMAND_ID);

	@BeforeEach
	void setup() throws JsonProcessingException {
		customizer.customize(restClientBuilder);
		MockRestServiceServer server = customizer.getServer(restClientBuilder);
		commandRestClient = new CommandRestClient(restClientBuilder.build());

		server.expect(requestTo(commandApi))
		  .andRespond(
			withSuccess(objectMapper.writeValueAsString(AntragraumproxyGrpcCommandTestFactory.createCommand()), MediaType.APPLICATION_JSON));
	}

	@Test
	void shouldCallGetCommand() {
		var command = commandRestClient.getCommand(COMMAND_ID, ADDRESS + COMMAND_URI);

		assertThat(command.getId()).isEqualTo(AntragraumproxyGrpcCommandTestFactory.ID);
	}

}