/*
 * Copyright (c) 2024.   Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten
 * des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung.
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.common;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.jupiter.MockitoExtension;
import org.springframework.http.HttpStatus;
import org.springframework.web.context.request.WebRequest;

@ExtendWith(MockitoExtension.class)
public class ExceptionControllerTest {

	@InjectMocks
	private ExceptionController exceptionController;

	@Nested
	class TestHandleAddressNotFoundException {

		@Mock
		private AddressNotFoundException exception;

		@Test
		void shouldReturnMessage() {
			var message = exceptionController.handleAddressNotFoundException(exception);

			assertThat(message).isNotNull();
		}

	}

	@Nested
	class TestHandleNotFoundException {

		@Mock
		private NotFoundException exception;

		@Test
		void shouldReturnMessage() {
			var message = exceptionController.handleNotFoundException(exception);

			assertThat(message).isNotNull();
		}

	}

	@Nested
	class TestHandleGeneralException {

		@Mock
		private TechnicalException exception;

		@Test
		void shouldReturnMessage() {
			var message = exceptionController.handleGeneralException(exception);

			assertThat(message).isNotNull();
		}

	}

	@Nested
	class TestHandleInvalidFileTypeException {

		@Mock
		private InvalidFileTypeException exception;

		@Mock
		private WebRequest webRequest;

		@Test
		void shouldHaveResponse() {
			var response = exceptionController.handleInvalidFileTypeException(exception, webRequest);

			assertThat(response).isNotNull();
		}

		@Test
		void shouldHaveNotAcceptableError() {
			var response = exceptionController.handleInvalidFileTypeException(exception, webRequest);

			assertThat(response.getStatusCode()).isEqualTo(HttpStatus.NOT_ACCEPTABLE);
		}

		@Test
		void shouldHaveMessage() {
			var response = exceptionController.handleInvalidFileTypeException(exception, webRequest);

			assertThat(response.getBody()).isEqualTo("File not acceptable");
		}

	}

	@Nested
	class TestHandleVirusFoundException {

		@Mock
		private VirusFoundException exception;

		@Mock
		private WebRequest webRequest;

		@Test
		void shouldHaveResponse() {
			var response = exceptionController.handleVirusFoundException(exception, webRequest);

			assertThat(response).isNotNull();
		}

		@Test
		void shouldHaveNotAcceptableError() {
			var response = exceptionController.handleVirusFoundException(exception, webRequest);

			assertThat(response.getStatusCode()).isEqualTo(HttpStatus.NOT_ACCEPTABLE);
		}

		@Test
		void shouldHaveMessage() {
			var response = exceptionController.handleVirusFoundException(exception, webRequest);

			assertThat(response.getBody()).isEqualTo("Virus found");
		}

	}

}
