/*
 * Copyright (c) 2023-2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.events;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

class NachrichtEventRemoteServiceTest {

	@Spy
	@InjectMocks
	private NachrichtEventRemoteService remoteService;
	@Mock
	private NachrichtEventRestClient restClient;
	@Mock
	private NachrichtEventMapper mapper;

	@DisplayName("Get nachricht event by id")
	@Nested
	class TestGetNachrichtEventById {

		private final NachrichtEvent nachrichtEvent = NachrichtEventTestFactory.create();

		@BeforeEach
		void init() {
			when(restClient.getNachrichtEventById(any())).thenReturn(GrpcInformationByIdResponseFactory.create());
			when(mapper.fromRest(any())).thenReturn(nachrichtEvent);
		}

		@Test
		void shouldCallRestClient() {
			remoteService.getNachrichtEventById(NachrichtEventTestFactory.ID);

			verify(restClient).getNachrichtEventById(NachrichtEventTestFactory.ID);
		}

		@Test
		void shouldCallMapper() {
			remoteService.getNachrichtEventById(NachrichtEventTestFactory.ID);

			verify(mapper).fromRest(GrpcInformationResponseTestFactory.NACHRICHT);
		}

		@Test
		void shouldReturnResult() {
			var mappedResult = remoteService.getNachrichtEventById(NachrichtEventTestFactory.ID);

			assertThat(mappedResult).usingRecursiveComparison().isEqualTo(nachrichtEvent);
		}

	}

	@DisplayName("Get nachricht events by postfach")
	@Nested
	class TestGetNachrichtEventsByPostfach {

		private final NachrichtEvent nachrichtEvent = NachrichtEventTestFactory.create();

		@BeforeEach
		void mock() {
			when(restClient.getNachrichtEventsByPostfach(any())).thenReturn(GrpcInformationResponseTestFactory.create());
			when(mapper.fromRest(any())).thenReturn(nachrichtEvent);
		}

		@Test
		void shouldCallRestClient() {
			remoteService.getNachrichtEventsByPostfach(NachrichtEventTestFactory.POSTFACH_ID);

			verify(restClient).getNachrichtEventsByPostfach(NachrichtEventTestFactory.POSTFACH_ID);
		}

		@Test
		void shouldCallMapper() {
			remoteService.getNachrichtEventsByPostfach(NachrichtEventTestFactory.POSTFACH_ID);

			verify(mapper).fromRest(GrpcInformationResponseTestFactory.NACHRICHT);
		}

		@Test
		void shouldReturnResult() {
			var mappedResult = remoteService.getNachrichtEventsByPostfach(NachrichtEventTestFactory.POSTFACH_ID);

			assertThat(mappedResult).containsExactly(nachrichtEvent);
		}

	}

}