/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.nachricht;

import static org.assertj.core.api.Assertions.*;

import java.util.Collections;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

class AntragraumProxyMapperTest {

	private final AntragraumProxyMapper mapper = Mappers.getMapper(AntragraumProxyMapper.class);

	@Nested
	class TestToRestProxyAntwort {

		private final ReplyNachricht replyNachricht = ReplyNachrichtTestFactory.create();

		@Test
		void shouldHaveRueckfrageId() {
			var grpcRueckfrageAnswer = mapper.toRestProxyAntwort(replyNachricht);

			assertThat(grpcRueckfrageAnswer.getRueckfrageId()).isEqualTo(ReplyNachrichtTestFactory.RUECKFRAGE_ID);
		}

		@Test
		void shouldHaveAnswerText() {
			var grpcRueckfrageAnswer = mapper.toRestProxyAntwort(replyNachricht);

			assertThat(grpcRueckfrageAnswer.getAnswerText()).isEqualTo(ReplyNachrichtTestFactory.TEXT);
		}

		@Test
		void shouldHaveAttachmentFileId() {
			var grpcRueckfrageAnswer = mapper.toRestProxyAntwort(replyNachricht);

			assertThat(grpcRueckfrageAnswer.getAttachmentFileId()).isEqualTo(Collections.emptyList());
		}

	}

}