/*
 * Copyright (c) 2023-2024.
 * Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.nachricht;

import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.util.List;
import java.util.UUID;

import de.ozgcloud.antragsraum.command.CommandTestFactory;
import de.ozgcloud.antragsraum.proxy.AntragraumproxyGrpcFindRueckfragenResponse;
import de.ozgcloud.antragsraum.proxy.AntragraumproxyGrpcGetRueckfrageResponse;
import de.ozgcloud.antragsraum.proxy.AntragraumproxyGrpcRueckfrage;
import de.ozgcloud.antragsraum.proxy.AntragraumproxyGrpcRueckfrageAnswer;
import de.ozgcloud.antragsraum.proxy.AntragraumproxyGrpcRueckfrageHead;
import de.ozgcloud.antragsraum.proxy.AntragraumproxyGrpcSendRueckfrageAnswerResponse;

public class AntragraumproxyGrpcRueckfrageTestFactory {

	public static final String RUECKFRAGE_ID = UUID.randomUUID().toString();
	public static final String VORGANG_ID = UUID.randomUUID().toString();
	public static final String VORGANG_NAME = NachrichtTestFactory.VORGANG_TITLE;
	public static final String ANSWER_FILE_ID = UUID.randomUUID().toString();
	public static final String ANSWER_ID = UUID.randomUUID().toString();
	public static final String TEXT = """
	  Lorem ipsum dolor sit amet, consetetur sadipscing elitr,
	   sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat,
	   sed diam voluptua. At vero eos et accusam et justo duo dolores et ea rebum.
	   
	   Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.
	   Lorem ipsum dolor sit amet, consetetur sadipscing elitr.
	  """;
	public static final String ANSWER_TEXT = """
	  ANTWORT Stet clita kasd gubergren, no sea takimata sanctus est Lorem ipsum dolor sit amet.
	   Lorem ipsum dolor sit amet, consetetur sadipscing elitr.
	  """;
	public static final String SEND_AT = "2022-10-26T09:26:25";
	public static final String SEND_AT_LONG = "2022-10-26T09:26:25.242804292Z[UTC]";
	public static final long SEND_AT_DATE = LocalDateTime.parse(SEND_AT).toEpochSecond(ZoneOffset.UTC) * 1000;
	public static final String ANSWERED_AT = "2022-10-27T12:00:00";
	public static final long ANSWERED_AT_DATE = LocalDateTime.parse(ANSWERED_AT).toEpochSecond(ZoneOffset.UTC) * 1000;
	public static final boolean ACCESSIBLE = true;
	public static final String TRUST_LEVEL = "LOW";
	public static final String STATUS = "ANSWERED";

	static AntragraumproxyGrpcGetRueckfrageResponse createGetRueckfrageResponse() {
		var response = new AntragraumproxyGrpcGetRueckfrageResponse();
		response.setRueckfrage(createRueckfrage());
		return response;
	}

	static AntragraumproxyGrpcRueckfrage createRueckfrage() {
		var rueckfrage = new AntragraumproxyGrpcRueckfrage();
		rueckfrage.setId(RUECKFRAGE_ID);
		rueckfrage.setVorgangId(VORGANG_ID);
		rueckfrage.setVorgangName(VORGANG_NAME);
		rueckfrage.setText(TEXT);
		rueckfrage.setSentAt(SEND_AT);
		rueckfrage.setAnsweredAt(ANSWERED_AT);
		rueckfrage.setAccessible(ACCESSIBLE);
		rueckfrage.setTrustLevel(TRUST_LEVEL);
		rueckfrage.setStatus(STATUS);
		rueckfrage.setAttachmentFileId(
		  List.of(NachrichtTestFactory.ATTACHMENT_ID_1, NachrichtTestFactory.ATTACHMENT_ID_2));
		return rueckfrage;
	}

	static AntragraumproxyGrpcRueckfrage createRueckfrageWithReply() {
		var rueckfrage = createRueckfrage();
		rueckfrage.setAnswers(List.of(createRueckfrageAnswer()));
		return rueckfrage;
	}

	static AntragraumproxyGrpcRueckfrageAnswer createRueckfrageAnswer() {
		var antwort = new AntragraumproxyGrpcRueckfrageAnswer();
		antwort.setRueckfrageId(ANSWER_ID);
		antwort.setAnswerText(ANSWER_TEXT);
		antwort.setSentAt(SEND_AT);
		antwort.setAttachmentFileId(List.of(ANSWER_FILE_ID));
		return antwort;
	}

	static AntragraumproxyGrpcFindRueckfragenResponse createFindRueckfragenResponse() {
		var response = new AntragraumproxyGrpcFindRueckfragenResponse();
		response.setRueckfrageHead(List.of(createRueckfrageHead()));
		return response;
	}

	static AntragraumproxyGrpcRueckfrageHead createRueckfrageHead() {
		var rueckfrageHeader = new AntragraumproxyGrpcRueckfrageHead();
		rueckfrageHeader.setId(RUECKFRAGE_ID);
		rueckfrageHeader.setVorgangId(VORGANG_ID);
		rueckfrageHeader.setVorgangName(VORGANG_NAME);
		rueckfrageHeader.setSentAt(SEND_AT);
		rueckfrageHeader.setAnsweredAt(ANSWERED_AT);
		rueckfrageHeader.setAccessible(ACCESSIBLE);
		rueckfrageHeader.setTrustLevel(TRUST_LEVEL);
		rueckfrageHeader.setStatus(STATUS);

		return rueckfrageHeader;
	}

	static AntragraumproxyGrpcSendRueckfrageAnswerResponse createSendRueckfrageAnswerResponse() {
		var response = new AntragraumproxyGrpcSendRueckfrageAnswerResponse();
		response.setCommandId(CommandTestFactory.ID);
		return response;
	}

}
