/*
 * Copyright (c) 2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.antragsraum.security;

import static org.assertj.core.api.Assertions.*;

import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.util.Date;

import org.junit.jupiter.api.Test;

class UserTest {

	@Test
	void getAuthorities() {
		var user = UserTestFactory.create();

		assertThat(user.getAuthorities()).isNotNull();
		assertThat(user.getAuthorities().iterator().next().getAuthority()).isEqualTo(DefaultRole.ROLE);
	}

	@Test
	void credentialsShouldBeExpired() {
		var expiredUser = UserTestFactory.createBuilder().tokenExpiresAt(Date.from(LocalDateTime.now().minusDays(1).toInstant(ZoneOffset.UTC)))
		  .build();

		assertThat(expiredUser.isCredentialsNonExpired()).isFalse();
	}

	@Test
	void credentialsShouldNotBeExpired() {
		var user = UserTestFactory.createBuilder().tokenExpiresAt(Date.from(LocalDateTime.now().plusHours(1).toInstant(ZoneOffset.UTC))).build();

		assertThat(user.isCredentialsNonExpired()).isTrue();
	}

}